@@ -1,8 +1,10 @@
 from .client import ElasticClient
-from .interfaces import IElasticClient
 
 
 def client_from_config(settings, prefix='elastic.'):
+    """
+    Instantiate and configure an Elasticsearch from settings.
+    """
     return ElasticClient(
         servers=settings.get(prefix + 'servers', ['localhost:9200']),
         timeout=settings.get(prefix + 'timeout', 1.0),
@@ -17,11 +19,15 @@ def includeme(config):
     client = client_from_config(settings)
     client.ensure_index()
 
-    registry.registerUtility(client, IElasticClient)
+    registry.pyramid_es_client = client
 
 
 def get_client(request):
+    """
+    Get the registered Elasticsearch client. The supplied argument can be
+    either a ``Request`` instance or a ``Registry``.
+    """
     registry = getattr(request, 'registry', None)
     if registry is None:
         registry = request
-    return registry.getUtility(IElasticClient)
+    return registry.pyramid_es_client
